@@ -1,7 +1,7 @@
 package Data::Sah::Compiler::perl;
 
 our $DATE = '2015-01-02'; # DATE
-our $VERSION = '0.37'; # VERSION
+our $VERSION = '0.38'; # VERSION
 
 use 5.010;
 use Moo;
@@ -266,6 +266,8 @@ sub expr_validator_sub {
 }
 
 sub _str2reliteral {
+    require re;
+
     my ($self, $cd, $str) = @_;
 
     my $re;
@@ -277,9 +279,16 @@ sub _str2reliteral {
     }
 
     # i don't know if this is safe?
-    $re = "$re";
-    $re =~ s!/!\\/!g;
-    $re;
+    my ($pat, $mod) = re::regexp_pattern($re);
+
+    # let's be 5.10-compat for now instead of potentially producing 5.14
+    # stringification which is not supported in <5.14.
+    $pat =~ s|(?<!\\)((?:\\\\)*)/|$1\\/|g; # escape non-escaped slashes
+    if ($mod) {
+        "(?:(?$mod-)$pat)";
+    } else {
+        $pat;
+    }
 }
 
 1;
@@ -297,7 +306,7 @@ Data::Sah::Compiler::perl - Compile Sah schema to Perl code
 
 =head1 VERSION
 
-This document describes version 0.37 of Data::Sah::Compiler::perl (from Perl distribution Data-Sah), released on 2015-01-02.
+This document describes version 0.38 of Data::Sah::Compiler::perl (from Perl distribution Data-Sah), released on 2015-01-02.
 
 =head1 SYNOPSIS
 
